==> openjdk-11_11~24.orig.tar.xz: openjdk-11-11~24/test/hotspot/jtreg/gc/cslocker/libTestCSLocker.c <==
/*
 * Copyright (c) 2007, 2017 Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#include <jni.h>

static volatile int release_critical = 0;

JNIEXPORT jboolean JNICALL Java_CSLocker_lock
  (JNIEnv *env, jobject obj, jintArray array)
{
    jboolean retval = JNI_TRUE;
    void *nativeArray = (*env)->GetPrimitiveArrayCritical(env, array, 0);

    if (nativeArray == NULL) {
        retval = JNI_FALSE;
    }

    // deadblock
    while (!release_critical) /* empty */;

    (*env)->ReleasePrimitiveArrayCritical(env, array, nativeArray, 0);
    return retval;
}

JNIEXPORT void JNICALL Java_CSLocker_unlock
  (JNIEnv *env, jobject obj)
{
    release_critical = 1;
}

==> openjdk-14_14~19.orig.tar.xz: openjdk-14-14~19/test/hotspot/jtreg/gc/cslocker/libTestCSLocker.c <==
/*
 * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#include <jni.h>

static volatile int release_critical = 0;

JNIEXPORT jboolean JNICALL Java_gc_cslocker_CSLocker_lock
  (JNIEnv *env, jobject obj, jintArray array)
{
    jboolean retval = JNI_TRUE;
    void *nativeArray = (*env)->GetPrimitiveArrayCritical(env, array, 0);

    if (nativeArray == NULL) {
        retval = JNI_FALSE;
    }

    // deadblock
    while (!release_critical) /* empty */;

    (*env)->ReleasePrimitiveArrayCritical(env, array, nativeArray, 0);
    return retval;
}

JNIEXPORT void JNICALL Java_gc_cslocker_CSLocker_unlock
  (JNIEnv *env, jobject obj)
{
    release_critical = 1;
}
